@@ -5,7 +5,13 @@ import shutil
 import sys
 from pathlib import Path
 
-import tomli
+try:
+    import tomllib as tomli  # type: ignore
+except ImportError:
+    try:
+        from pdm.pep517._vendor import tomli
+    except ImportError:
+        import tomli
 from pdm.builders.sdist import SdistBuilder
 from pdm.builders.wheel import WheelBuilder
 from pdm.cli.commands.base import BaseCommand
@@ -120,7 +126,9 @@ class MinaBuildCommand(BaseCommand):
         if not (project.root / "pyproject.toml").exists():
             project.core.ui.echo("No pyproject.toml found.", err=True)
             sys.exit(1)
-        pyproj = tomli.loads((project.root / "pyproject.toml").read_text())
+        pyproj = tomli.loads(
+            (project.root / "pyproject.toml").read_text(encoding="utf-8")
+        )
         mina_packages = pyproj.get("tool", {}).get("mina", {}).get("packages", [])
         packages = options.packages
 
