@@ -1,7 +1,13 @@
 import sys
 from argparse import Namespace
 
-import tomli
+try:
+    import tomllib as tomli  # type: ignore
+except ImportError:
+    try:
+        from pdm.pep517._vendor import tomli
+    except ImportError:
+        import tomli
 from pdm.cli.commands.base import BaseCommand
 from pdm.project.core import Project
 
@@ -11,7 +17,9 @@ class MinaPackagesListCommand(BaseCommand):
         if not (project.root / "pyproject.toml").exists():
             project.core.ui.echo("No pyproject.toml found.", err=True)
             sys.exit(1)
-        pyproj = tomli.loads((project.root / "pyproject.toml").read_text())
+        pyproj = tomli.loads(
+            (project.root / "pyproject.toml").read_text(encoding="utf-8")
+        )
         mina_packages = pyproj.get("tool", {}).get("mina", {}).get("packages", [])
         if not mina_packages:
             project.core.ui.echo(
